define(["qlik", "jquery", "./label-definition"], function (qlik, $, label) {
	return {
		type: "items",
		component: "accordion",
		items: {
			dimensions: {
				uses: "dimensions",
				min: 1,
				items: {
					partOfKey: {
						ref: "qDef.partOfKey",
						label: "Dimension is part of key",
						type: "boolean",
						defaultValue: false
					},
					isHidden: {
						ref: "qDef.isHidden",
						label: "Dimension is hidden",
						type: "boolean",
						defaultValue: false
					},
					colorExpression: {
						component: "expression",
						label: "Font color expression",
						ref: "qAttributeExpressions.0.qExpression",
						expression: "optional"
					},
					BackgroundColorExpression: {
						component: "expression",
						label: "Background color expression",
						ref: "qAttributeExpressions.1.qExpression",
						expression: "optional"
					},
					LockExpression: {
						component: "expression",
						label: "Lock Input row expression",
						ref: "qAttributeExpressions.2.qExpression",
						expression: "optional"
					},
					fontWeight: {
						type: "string",
						component: "dropdown",
						label: "Font Weight",
						ref: "qDef.styleFontWeight",
						options: [{
							value: "normal",
							label: "Normal"
						}, {
							value: "bold",
							label: "Bold"
						}],
						defaultValue: "normal"
					}
				}
			},
			measures: {
				uses: "measures",
				min: 0,
				items: {
					colorExpression: {
						component: "expression",
						label: "Font color expression",
						ref: "qAttributeExpressions.0.qExpression",
						expression: "optional"
					},
					backgroundColorExpression: {
						component: "expression",
						label: "Background color expression",
						ref: "qAttributeExpressions.1.qExpression",
						expression: "optional"
					},
					fontWeight: {
						type: "string",
						component: "dropdown",
						label: "Font Weight",
						ref: "qDef.styleFontWeight",
						options: [{
							value: "normal",
							label: "Normal"
						}, {
							value: "bold",
							label: "Bold"
						}],
						defaultValue: "normal"
					}
				}
			},
			addons: {
				uses: "addons",
				items: {
					dataHandling: {
						uses: "dataHandling"

					}
				}
			},
			sorting: {
				uses: "sorting"
			},
			settings: {
				uses: "settings",
				items: {
					tableStyling: {
						type: "items",
						label: "Table Styling",
						items: {
							headerfontWeight: {
								type: "string",
								component: "dropdown",
								label: "Header font Weight",
								ref: "props.tableStyling.headerFontWeight",
								options: [{
									value: "normal",
									label: "Normal"
								}, {
									value: "bold",
									label: "Bold"
								}],
								defaultValue: "normal"
							},
							inputLocation: {
								type: "string",
								component: "dropdown",
								label: "Input location",
								ref: "props.tableStyling.inputLocation",
								options: [{
									value: "left",
									label: "Left"
								}, {
									value: "right",
									label: "Right"
								}],
								defaultValue: "right"
							},
							showActionButton: {
								ref: "props.tableStyling.showActionButton",
								label: "Show action button",
								type: "boolean",
								defaultValue: true
							},
							showLastChange: {
								ref: "props.tableStyling.showLastChange",
								label: "Show last change",
								type: "boolean",
								defaultValue: true
							},
							showLastActionStatus: {
								ref: "props.tableStyling.showLastActionStatus",
								label: "Show last action status",
								type: "boolean",
								defaultValue: true
							},
							showGeneralStatus: {
								ref: "props.tableStyling.showGeneralStatus",
								label: "Show general status",
								type: "boolean",
								defaultValue: true
							},
							hideFirstColumn: {
								ref: "props.tableStyling.hideFirstColumn",
								label: "Hide first column",
								type: "boolean",
								defaultValue: false
							},

						}
					},
					label: label,
					aboutHeader: {
						type: "items",
						label: "About",
						items: {
							text1: {
								label: "For interactive writeback",
								component: "text"
							},
							text2: {
								label: "User Guide:",
								component: "text"
							},
							text3: {
								label: "Add the field with the reference id first dimension",
								component: "text"
							},
							text4: {
								label: "Add other fields to be shown",
								component: "text"
							},
							text5: {
								label: "The rigth order is important",
								component: "text"
							},
							text6: {
								label: "Extension by Stretch Qonnect ApS",
								component: "text"
							}
						}
					},
				}
			},
			inputDefinition: {
				label: "Input definition",
				type: "items",
				items: {
					inputDefinitionArray: {
						type: "array",
						ref: "props.inputDefinitionsArray",
						label: "Input Definitions",
						itemTitleRef: "header",
						allowAdd: true,
						allowRemove: true,
						addTranslation: "Add definition",
						items: {
							header: {
								ref: "header",
								label: "Header",
								type: "string",
								defaultValue: "header 1"
							},
							dataid: {
								ref: "id",
								label: "Dataid (no spaces)",
								type: "string",
								defaultValue: "dataid1"
							},
							placeholder: {
								ref: "attributes.placeholder",
								label: "Placeholder text",
								type: "string",
								//defaultValue: "your data"	
							},
							type: {
								type: "string",
								component: "dropdown",
								label: "Type",
								ref: "type",
								options: [{
									value: "textbox",
									label: "Textbox"
								}, {
									value: "text",
									label: "Text"
								}, {
									value: "number",
									label: "Number"
								}, {
									value: "checkbox",
									label: "Checkbox"
								}, {
									value: "date",
									label: "Date"
								}, {
									value: "select",
									label: "Dropdown"
								}, {
									value: "radio",
									label: "Radio button list"
								}, {
									value: "range",
									label: "Slider"
								}],
								defaultValue: "text"
							},
							//-- type dependent options --
							//multiple inputs orientations
							inputOrientationVertical: {
								label: "Display inputs vertically",
								type: "boolean",
								ref: "layout.inputOrientationVertical",
								show: function (input) {
									return input.type == "radio";
								}
							},
							//Select
							valuesText: {
								label: "Add values for input",
								component: "text",
								show: function (input) {
									return input.type == "select" || input.type == "radio";
								}
							},
							values: {
								type: "array",
								ref: "values",
								label: "Values",
								itemTitleRef: "value",
								allowAdd: true,
								allowRemove: true,
								addTranslation: "Add values",
								items: {
									value: {
										ref: "value",
										label: "Value",
										type: "string",
										defaultValue: "value1"
									},
									key: {
										ref: "key",
										label: "Key",
										type: "string",
										defaultValue: "key1"
									}
								},
								show: function (input) {
									return input.type == "select" || input.type == "radio";
								}
							},
							//range
							rangeMin: {
								label: "Range min",
								type: "number",
								ref: "attributes.min",
								show: function (input) {
									return input.type == "range";
								}
							},
							rangeMax: {
								label: "Range max",
								type: "number",
								ref: "attributes.max",
								show: function (input) {
									return input.type == "range";
								}
							},
							rangeStep: {
								label: "Range stepsize",
								type: "number",
								ref: "attributes.step",
								show: function (input) {
									return input.type == "range";
								}
							},

							//-- attributes --
							attributeText: {
								label: "Optional. Add attributes to inputs",
								component: "text"
							},
							optionalAttributes: {
								type: "array",
								ref: "optionalAttributes",
								label: "Attributes",
								itemTitleRef: "attribute",
								allowAdd: true,
								allowRemove: true,
								addTranslation: "Add attributes",
								items: {
									attribute: {
										ref: "attribute",
										label: "Attribute",
										type: "string"
									},
									value: {
										ref: "value",
										label: "Value",
										type: "string"
									}
								}
							}
						}
					}
				}
			},
			data: {
				label: "Table and data settings",
				type: "items",
				items: {
					initFetchRows: {
						ref: "qHyperCubeDef.qInitialDataFetch.0.qHeight",
						label: "Initial Rows To Fetch",
						type: "number",
						expression: "optional",
						placeholder: 50,
						defaultValue: 50
					},
					keySeperator: {
						ref: "props.keySeperator",
						label: "Key Separator",
						type: "string",
						expression: "optional",
						placeholder: "|",
						defaultValue: "|"
					},						
					dataColumnName: {
						ref: "props.dataColumnName",
						label: "Data Field Name In Database",
						type: "string",
						expression: "optional",
						placeholder: "data",
						defaultValue: "data"
					},
					useUniqueKeys: {
						ref: "props.useUniqueKeys",
						label: "Use Unique Keys When Fetching Data",
						type: "boolean",
						placeholder: true,
						defaultValue: true
					},
					inputDefinition: {
						ref: "props.inputDefinition",
						label: "Header and id definition - Depricated",
						type: "string",
						component: "textarea",										
						show: function(input) {
							return !!input.props.inputDefinition && input.props.inputDefinition.length > 0;
						}
					},
				}
			},				
			service: {
				label: "Service settings",					
				type: "items",
				items: {
					proxyHost: {
						ref: "props.service.proxyBaseUrl",
						label: "Proxy Host",
						type: "string",
						expression: "optional",
						defaultValue: "https://writeback.qloudcover.com",
						placeholder: "https://writeback.qloudcover.com/"
					},
					proxyPort: {
						ref: "props.service.proxyPort",
						label: "Proxy Port",
						type: "string",
						expression: "optional",
						defaultValue: "443",
						placeholder: "443"
					},
					proxyAPIEndpoint: {
						ref: "props.service.proxyEndpoint",
						label: "Proxy API Endpoint",
						type: "string",
						expression: "optional",
						placeholder: "/api/Writeback/"
					},
					extensionID: {
						ref: "props.service.extensionID",
						label: "Solution Extension ID",
						type: "string",
						expression: "optional",
						defaultValue: "",
						placeholder: "mySolutionExtensionID"
					},
					authenticationType: {
						type: "string",
						component: "dropdown",
						label: "Authentication Type",
						ref: "props.service.authentication.type",
						options: [{
							value: "NTLM",
							label: "Windows NTLM"
						}, {
							value: "HEADER",
							label: "Header & Cookie"
						}],
						defaultValue: "HEADER"
					},
					apiKey: {
						ref: "props.service.authentication.apiKey",
						label: "Service API Key",
						type: "string",
						expression: "optional",
						show: function(input) {
							return !!input.props.service.authentication && !!input.props.service.authentication.type && input.props.service.authentication.type == "HEADER";
						}
					},						
					authenticationIsEnabled: {
						ref: "props.service.authentication.isEnabled",
						label: "Require Authentication",
						type: "boolean",
						defaultValue: true
					},
					authenticationIsInteractive: {
						ref: "props.service.authentication.isInteractive",
						label: "Require Interactive Authentication",
						type: "boolean",
						defaultValue: false
					},

					showDebug: {
						ref: "props.showDebug",
						label: "Enable Debug",
						type: "boolean",
						defaultValue: false
					},
					
				}
			}
		}
	}

});